@@ -4,5 +4,5 @@ import sys
 
 from subtractor.cli import main
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     sys.exit(main(sys.argv[1:]))  # pragma: no cover
